#!/usr/bin/python

import tetrisdata
import random
import copy
import pygtk
import gtk
import gtk.glade
import gobject
import cairo

class PyTetris:
    """PyTetris GTK Interface"""

    def __init__(self):
        self.gs = tetrisdata.GameState()
        self.gladefile = "tetrisui.glade"
        self.wTree = gtk.glade.XML(self.gladefile)
        self.window = self.wTree.get_widget("pytetris")
        self.drawAreaGame = self.wTree.get_widget("drawAreaGame")
        self.drawAreaNext = self.wTree.get_widget("drawAreaNext")
        if(self.window):
            self.window.connect("destroy", gtk.main_quit)
        self.drawAreaGame.connect("expose_event", self.expose)
        self.window.connect("key_press_event", self.keyhandler)
        gobject.timeout_add(1000,self.timedMove)

    def expose(self, widget, event):
        self.context = widget.window.cairo_create()
        
        #set clip region
        self.context.rectangle(event.area.x, event.area.y,
                               event.area.width, event.area.height)
        self.context.clip()
        self.draw()
        return False

    def draw(self):
        #Draw the background
        self.context.set_source_rgb(0,0,0)
        self.context.rectangle(0,0,*self.drawAreaGame.window.get_size())
        self.context.fill()
        #Draw the current piece
        for (x,y) in self.gs._piece._coor:
            self.context.set_source_rgb(*colourToRGB(self.gs._piece._colour))
            self.context.rectangle(20*x,20*y,20,20)
            self.context.fill()
        #Draw the board
        for i in range(0,18):
            for j in range(0,11):
                colour = self.gs._board._board[(j,i)]
                if colour != "None":
                    self.context.set_source_rgb(*colourToRGB(colour))
                    self.context.rectangle(20*j,20*i,20,20)
                    self.context.fill()

    def keyhandler(self, widget, event):
        self.context = self.drawAreaGame.window.cairo_create()
        
        if event.keyval == gtk.keysyms.Up: self.gs.makeMove("Rotate")
        elif event.keyval == gtk.keysyms.Down: self.gs.makeMove("Down")
        elif event.keyval == gtk.keysyms.Right: self.gs.makeMove("Right")
        elif event.keyval == gtk.keysyms.Left: self.gs.makeMove("Left")

        self.draw()
        return True

    def timedMove(self):
        self.context = self.drawAreaGame.window.cairo_create()
        self.gs.makeMove("Down")
        self.draw()
        return True


def colourToRGB(colour):
    if colour == "Red": return (1,0,0)
    elif colour == "Green": return (0,1,0)
    elif colour == "Blue": return (0,0,1)
    elif colour == "White": return (1,1,1)
    elif colour == "Purple": return (1,0,1)
    elif colour == "Orange": return (1,0.5,0)
    else: return (1,1,0)

random.seed()

if __name__ == "__main__":
    pytetris = PyTetris()
    pytetris.window.show_all()
    gtk.main()

